-- texturing of multiple quads
local sin, cos, atan2, sqrt, pi, floor = math.sin, math.cos, math.atan2, math.sqrt, math.pi, math.floor
local gr, tm, ky,li = love.graphics, love.timer, love.keyboard, love.image

local tex = require 'texture_effect'

function love.load()
	tex.load()
	gr.setBackgroundColor( 55, 55, 255, 255 )
	gr.setCaption( 'Applying a single texture over multiple quads' )
	image			= gr.newImage( 'Checkerboard.jpg' )
	width,height	= gr.getWidth(), gr.getHeight()
	quads, cd		= grid_pattern(image)
	show_grid		= false
	end

function love.draw()
	for j = 1, #quads do
		for i = 1,#quads[j] do
			tex.quad( image, quads[j][i],{cd[j][i][1],cd[j][i][2]},{cd[j][i][3],cd[j][i][4]})
			end
		end
	if show_grid then draw_grid() end
	gr.setColor( 255, 255, 255, 255 )
	gr.draw(image, 550, 325, 0, 0.25, 0.25 )
	gr.setColor( 255, 255, 0, 255 )
	gr.print( 'original image',		600,	500 )
	gr.print( 'distorted image',	200,	500 )
	gr.print( '< q > to show quad pattern',	10, height-20 )
	gr.print( 'fps: '..tm.getFPS( ), width-100, height-20 )
	--n=3
	--gr.print('{'..cd[n][n][1]..','..cd[n][n][2]..'}',500,100)
	--gr.print('{'..cd[n][n][3]..','..cd[n][n][4]..'}',500,120)
	end

function love.keypressed( key )
	if key == 'escape' 	then love.event.quit()			end
	if key == 'q'		then show_grid = not show_grid	end
	end

function love.update( dt )
	end

function draw_grid()
	gr.setColor( 0, 0, 0, 255 )
	for j = 1, #quads - 1 do
		for i = 1, #quads[j] - 1 do
			gr.line(	quads[j][i][1][1], quads[j][i][1][2],
						quads[j][i][2][1], quads[j][i][2][2],
						quads[j][i][3][1], quads[j][i][3][2],
						quads[j][i][4][1], quads[j][i][4][2],
						quads[j][i][1][1], quads[j][i][1][2])
			end
		end
	end

function grid_pattern(image)
	image_width = image:getWidth()
	image_height = image:getHeight()
	-- Generate pattern for generating quads
	gx, gy		= {0}, {0}
	ix			= 1
	for i		= 0, pi, pi/8 do
		ix		= ix + 1
		gx[ix]	= gx[ix-1]+3*sin(i)
		gy[ix]	= gy[ix-1]+3*sin(i)
		end
	scale_x		= 30
	scale_y		= 30
	of_x,of_y	= 50,20
	ot_x,ot_y	= 100,20
	-- set texturing parameters
	tex.x		= 35/image_width		-- x & y coords for texture
	tex.y		= 35/image_height
	tex.w,tex.h	= 70/image_width, 70/image_height	-- how large a piece of the image to use
	tx, ty		= {}, {}
	for i = 1, #gx do
		gx[i]	= scale_x * gx[i] + of_x
		gy[i]	= scale_y * gy[i] + of_y
		tx[i]	= tex.x + tex.w * (i-1)
		ty[i]	= tex.y + tex.h * (i-1)
		end
	quad		= {}

	for j		= 1, #gy - 1 do
		quad[j] = {}
		for i	= 1, #gx - 1 do
			quad[j][i] = { {gx[i],gy[j]}, {gx[i+1],gy[j]}, {gx[i+1],gy[j+1]}, {gx[i],gy[j+1]} }
			end
		end
	fragments		= {}
	for j = 1, #gy do
		fragments[j] = {}
		for i = 1, #gx do
			fragments[j][i] = { tx[i], ty[i], tex.w, tex.h }
			end
		end
	return quad, fragments
	end
